@@ -167,10 +167,11 @@ static void
 _nc_data_bao_dv_mean_func (NcmDataGaussDiag *diag, NcmMSet *mset, NcmVector *vp)
 {
   NcDataBaoDV *bao_dv = NC_DATA_BAO_DV (diag);
-  NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ()));
+  NcHICosmo *cosmo    = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ()));
+  const guint np      = ncm_data_gauss_diag_get_size (diag);
   guint i;
 
-  for (i = 0; i < diag->np; i++)
+  for (i = 0; i < np; i++)
   {
     const gdouble z = ncm_vector_get (bao_dv->x, i);
     const gdouble DV = nc_distance_dilation_scale (bao_dv->dist, cosmo, z) * nc_hicosmo_RH_Mpc (cosmo);
@@ -182,11 +183,12 @@ static void
 _nc_data_bao_dv_set_size (NcmDataGaussDiag *diag, guint np)
 {
   NcDataBaoDV *bao_dv = NC_DATA_BAO_DV (diag);
+  const guint cnp     = ncm_data_gauss_diag_get_size (diag);
 
-  if ((np == 0) || (np != diag->np))
+  if ((np == 0) || (np != cnp))
     ncm_vector_clear (&bao_dv->x);
 
-  if ((np != 0) && (np != diag->np))
+  if ((np != 0) && (np != cnp))
     bao_dv->x = ncm_vector_new (np);
 
   /* Chain up : end */
