@@ -13,12 +13,12 @@
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,10 +27,10 @@
  * SECTION:nc_data_bao_empirical_fit_2d
  * @title: NcDataBaoEmpiricalFit2d
  * @short_description: Baryon oscillation data -- $D_H / r_d$ and $D_t / r_d$ empirical likelihood.
- * 
- * This object implements the BAO data when its likelihood function is provided, 
+ *
+ * This object implements the BAO data when its likelihood function is provided,
  * e.g., [Bautista et al. (2017)][XBautista2017].
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,11 +47,11 @@ enum
 {
   PROP_0,
   PROP_DH_RD_FIDUC,
-  PROP_DT_RD_FIDUC, 
+  PROP_DT_RD_FIDUC,
   PROP_Z,
   PROP_M2LNP,
   PROP_DIST,
-	PROP_SIZE 
+  PROP_SIZE
 };
 
 G_DEFINE_TYPE (NcDataBaoEmpiricalFit2d, nc_data_bao_empirical_fit_2d, NCM_TYPE_DATA_DIST2D);
@@ -61,10 +61,10 @@ nc_data_bao_empirical_fit_2d_init (NcDataBaoEmpiricalFit2d *bao_ef)
 {
   bao_ef->Dh_rd_fiduc = 0.0;
   bao_ef->Dt_rd_fiduc = 0.0;
-  bao_ef->z        = 0.0;
-  bao_ef->m2lnp    = NULL;
-  bao_ef->p        = NULL;
-  bao_ef->dist     = nc_distance_new (2.0);
+  bao_ef->z           = 0.0;
+  bao_ef->m2lnp       = NULL;
+  bao_ef->p           = NULL;
+  bao_ef->dist        = nc_distance_new (2.0);
 }
 
 static void
@@ -76,7 +76,7 @@ nc_data_bao_empirical_fit_2d_constructed (GObject *object)
     NcDataBaoEmpiricalFit2d *bao_ef = NC_DATA_BAO_EMPIRICAL_FIT_2D (object);
 
     ncm_stats_dist2d_prepare (bao_ef->p);
-    
+
     ncm_data_set_init (NCM_DATA (bao_ef), TRUE);
   }
 }
@@ -85,6 +85,7 @@ static void
 nc_data_bao_empirical_fit_2d_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
   NcDataBaoEmpiricalFit2d *bao_ef = NC_DATA_BAO_EMPIRICAL_FIT_2D (object);
+
   g_return_if_fail (NC_IS_DATA_BAO_EMPIRICAL_FIT_2D (object));
 
   switch (prop_id)
@@ -102,7 +103,7 @@ nc_data_bao_empirical_fit_2d_set_property (GObject *object, guint prop_id, const
       ncm_spline2d_clear (&bao_ef->m2lnp);
       ncm_stats_dist2d_clear (&bao_ef->p);
       bao_ef->m2lnp = g_value_dup_object (value);
-      bao_ef->p = NCM_STATS_DIST2D (ncm_stats_dist2d_spline_new (bao_ef->m2lnp));
+      bao_ef->p     = NCM_STATS_DIST2D (ncm_stats_dist2d_spline_new (bao_ef->m2lnp));
       break;
     case PROP_DIST:
       nc_data_bao_empirical_fit_2d_set_dist (bao_ef, g_value_get_object (value));
@@ -117,6 +118,7 @@ static void
 nc_data_bao_empirical_fit_2d_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
   NcDataBaoEmpiricalFit2d *bao_ef = NC_DATA_BAO_EMPIRICAL_FIT_2D (object);
+
   g_return_if_fail (NC_IS_DATA_BAO_EMPIRICAL_FIT_2D (object));
 
   switch (prop_id)
@@ -149,9 +151,9 @@ nc_data_bao_empirical_fit_2d_dispose (GObject *object)
 
   ncm_spline2d_clear (&bao_ef->m2lnp);
   ncm_stats_dist2d_clear (&bao_ef->p);
-  
+
   nc_distance_clear (&bao_ef->dist);
-  
+
   /* Chain up : end */
   G_OBJECT_CLASS (nc_data_bao_empirical_fit_2d_parent_class)->dispose (object);
 }
@@ -159,8 +161,6 @@ nc_data_bao_empirical_fit_2d_dispose (GObject *object)
 static void
 nc_data_bao_empirical_fit_2d_finalize (GObject *object)
 {
-  
-
   /* Chain up : end */
   G_OBJECT_CLASS (nc_data_bao_empirical_fit_2d_parent_class)->finalize (object);
 }
@@ -171,7 +171,7 @@ static void _nc_data_bao_empirical_fit_2d_inv_pdf (NcmDataDist2d *dist2d, NcmMSe
 static void
 nc_data_bao_empirical_fit_2d_class_init (NcDataBaoEmpiricalFit2dClass *klass)
 {
-  GObjectClass* object_class = G_OBJECT_CLASS (klass);
+  GObjectClass *object_class       = G_OBJECT_CLASS (klass);
   NcmDataDist2dClass *bao_ef_class = NCM_DATA_DIST2D_CLASS (klass);
 
   object_class->constructed  = nc_data_bao_empirical_fit_2d_constructed;
@@ -223,40 +223,39 @@ nc_data_bao_empirical_fit_2d_class_init (NcDataBaoEmpiricalFit2dClass *klass)
   bao_ef_class->inv_pdf   = _nc_data_bao_empirical_fit_2d_inv_pdf;
 }
 
-static gdouble 
+static gdouble
 _nc_data_bao_empirical_fit_2d_m2lnL_val (NcmDataDist2d *dist2d, NcmMSet *mset, gdouble x, gdouble y)
 {
   NcDataBaoEmpiricalFit2d *bao_ef = NC_DATA_BAO_EMPIRICAL_FIT_2D (dist2d);
-  const gdouble alpha_par         = nc_data_bao_empirical_fit_2d_get_alpha_parallel (bao_ef, mset);
-  const gdouble alpha_per         = nc_data_bao_empirical_fit_2d_get_alpha_perpendicular (bao_ef, mset);
-  const gdouble alphax            = alpha_per - x;
-  const gdouble alphay            = alpha_par - y; 
-  gdouble m2lnL                   = ncm_stats_dist2d_eval_m2lnp (bao_ef->p, alphax, alphay);
+  const gdouble alpha_par = nc_data_bao_empirical_fit_2d_get_alpha_parallel (bao_ef, mset);
+  const gdouble alpha_per = nc_data_bao_empirical_fit_2d_get_alpha_perpendicular (bao_ef, mset);
+  const gdouble alphax = alpha_per - x;
+  const gdouble alphay = alpha_par - y;
+  gdouble m2lnL = ncm_stats_dist2d_eval_m2lnp (bao_ef->p, alphax, alphay);
   gdouble xl, xu, yl, yu;
 
   ncm_stats_dist2d_xbounds (bao_ef->p, &xl, &xu);
   ncm_stats_dist2d_ybounds (bao_ef->p, &yl, &yu);
 
 /*
-  printf ("x, y = % 22.15g, % 22.15g | m2lnL = % 22.15g (% 22.15g % 22.15g) (% 22.15g % 22.15g)\n",
-      alphax, alphay, m2lnL,
-      xl, xu, yl, yu);
-*/
+ *  printf ("x, y = % 22.15g, % 22.15g | m2lnL = % 22.15g (% 22.15g % 22.15g) (% 22.15g % 22.15g)\n",
+ *     alphax, alphay, m2lnL,
+ *     xl, xu, yl, yu);
+ */
 
   if (((alphax < xl) || (alphax > xu)) || ((alphay < yl) || (alphay > yu)))
     return GSL_POSINF;
   else
-    return m2lnL;  
+    return m2lnL;
 }
 
-static void 
+static void
 _nc_data_bao_empirical_fit_2d_inv_pdf (NcmDataDist2d *dist2d, NcmMSet *mset, gdouble u, gdouble v, gdouble *x, gdouble *y)
 {
   NcDataBaoEmpiricalFit2d *bao_ef = NC_DATA_BAO_EMPIRICAL_FIT_2D (dist2d);
 
   NCM_UNUSED (bao_ef);
   g_assert_not_reached ();
-  
 }
 
 /**
@@ -265,9 +264,9 @@ _nc_data_bao_empirical_fit_2d_inv_pdf (NcmDataDist2d *dist2d, NcmMSet *mset, gdo
  * @Dh_rd_fiduc: fiducial $D_H/r_d$
  * @Dt_rd_fiduc: fiducial $D_t/r_d$
  * @z: data redshift
- * 
+ *
  * Creates a new #NcDataBaoEmpiricalFit2d.
- * 
+ *
  * Returns: the newly created #NcDataBaoEmpiricalFit2d.
  */
 NcDataBaoEmpiricalFit2d *
@@ -295,15 +294,16 @@ nc_data_bao_empirical_fit_2d_new (NcmSpline2d *m2lnp, gdouble Dh_rd_fiduc, gdoub
 /**
  * nc_data_bao_empirical_fit_2d_new_from_file:
  * @filename: file containing a serialized #NcDataBaoEmpiricalFit2d.
- * 
+ *
  * Creates a new #NcDataBaoEmpiricalFit2d from @filename.
- * 
+ *
  * Returns: (transfer full): the newly created #NcDataBaoEmpiricalFit2d.
  */
 NcDataBaoEmpiricalFit2d *
 nc_data_bao_empirical_fit_2d_new_from_file (const gchar *filename)
 {
   NcDataBaoEmpiricalFit2d *bao_ef = NC_DATA_BAO_EMPIRICAL_FIT_2D (ncm_serialize_global_from_file (filename));
+
   g_assert (NC_IS_DATA_BAO_EMPIRICAL_FIT_2D (bao_ef));
 
   return bao_ef;
@@ -313,9 +313,9 @@ nc_data_bao_empirical_fit_2d_new_from_file (const gchar *filename)
  * nc_data_bao_empirical_fit_2d_new_from_id:
  * @dist: a #NcDistance
  * @id: a #NcDataBaoId
- * 
+ *
  * Creates a new #NcDataBaoEmpiricalFit2d from @id.
- * 
+ *
  * Returns: (transfer full): the newly created #NcDataBaoEmpiricalFit2d.
  */
 NcDataBaoEmpiricalFit2d *
@@ -323,6 +323,7 @@ nc_data_bao_empirical_fit_2d_new_from_id (NcDistance *dist, NcDataBaoId id)
 {
   NcDataBaoEmpiricalFit2d *bao_ef;
   gchar *filename;
+
   switch (id)
   {
     case NC_DATA_BAO_EMPIRICAL_FIT_2D_BAUTISTA2017:
@@ -345,7 +346,7 @@ nc_data_bao_empirical_fit_2d_new_from_id (NcDistance *dist, NcDataBaoId id)
 
   g_assert (NC_IS_DATA_BAO_EMPIRICAL_FIT_2D (bao_ef));
   g_assert (NCM_IS_DATA (bao_ef));
-   
+
   return bao_ef;
 }
 
@@ -353,15 +354,15 @@ nc_data_bao_empirical_fit_2d_new_from_id (NcDistance *dist, NcDataBaoId id)
  * nc_data_bao_empirical_fit_2d_get_alpha_perpendicular:
  * @bao_ef: a #NcDataBaoEmpiricalFit2d
  * @mset: a #NcmMSet
- * 
+ *
  * Calculates value of $\alpha_{\perp}$ given a #NcmMSet,
  * $$ \alpha_{perp} = \frac{[D_t(z)/r_d]}{[D_t(z)/r_d]_{fid}},$$
- * where $D_t(z)$ is the transverse comoving distance [nc_distance_transverse()], $r_d$ is the sound 
- * horizon [nc_distance_sound_horizon()] at the drag epoch, and 'fid' indicates fiducial. 
- * 
+ * where $D_t(z)$ is the transverse comoving distance [nc_distance_transverse()], $r_d$ is the sound
+ * horizon [nc_distance_sound_horizon()] at the drag epoch, and 'fid' indicates fiducial.
+ *
  * Returns: $\alpha_{\perp}$
  */
-gdouble 
+gdouble
 nc_data_bao_empirical_fit_2d_get_alpha_perpendicular (NcDataBaoEmpiricalFit2d *bao_ef, NcmMSet *mset)
 {
   NcHICosmo *cosmo         = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ()));
@@ -376,12 +377,12 @@ nc_data_bao_empirical_fit_2d_get_alpha_perpendicular (NcDataBaoEmpiricalFit2d *b
  * nc_data_bao_empirical_fit_2d_get_alpha_parallel:
  * @bao_ef: a #NcDataBaoEmpiricalFit2d
  * @mset: a #NcmMSet
- * 
+ *
  * Calculates value of $\alpha_{\parallel}$ given a #NcmMSet.
- * 
+ *
  * Returns: $\alpha_{\parallel}$
  */
-gdouble 
+gdouble
 nc_data_bao_empirical_fit_2d_get_alpha_parallel (NcDataBaoEmpiricalFit2d *bao_ef, NcmMSet *mset)
 {
   NcHICosmo *cosmo         = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ()));
@@ -396,13 +397,14 @@ nc_data_bao_empirical_fit_2d_get_alpha_parallel (NcDataBaoEmpiricalFit2d *bao_ef
  * nc_data_bao_empirical_fit_2d_set_dist:
  * @bao_ef: a #NcDataBaoEmpiricalFit2d
  * @dist: a #NcDistance
- * 
+ *
  * Sets the distance object.
- * 
+ *
  */
-void 
+void
 nc_data_bao_empirical_fit_2d_set_dist (NcDataBaoEmpiricalFit2d *bao_ef, NcDistance *dist)
 {
   nc_distance_clear (&bao_ef->dist);
   bao_ef->dist = nc_distance_ref (dist);
 }
+
