@@ -4,11 +4,11 @@
  *
  *  Sun April 7 16:59:36 2021
  *  Copyright  2021  Sandro Dias Pinto Vitenti
- *  <sandro@isoftware.com.br>
+ *  <vitenti@uel.br>
  ****************************************************************************/
 /*
  * ncm_iset.c
- * Copyright (C) 2021 Sandro Dias Pinto Vitenti <sandro@isoftware.com.br>
+ * Copyright (C) 2021 Sandro Dias Pinto Vitenti <vitenti@uel.br>
  *
  * numcosmo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -449,7 +449,7 @@ ncm_iset_get_subvector (NcmISet *iset, NcmVector *v, NcmVector *v_dup)
 
   if (v_dup != NULL)
   {
-    g_assert_cmpuint (self->n, ==, ncm_vector_len (v_dup));
+    g_assert_cmpuint (nsub, <=, ncm_vector_len (v_dup));
     sub = ncm_vector_get_subvector (v_dup, 0, nsub);
   }
   else
@@ -472,6 +472,57 @@ ncm_iset_get_subvector (NcmISet *iset, NcmVector *v, NcmVector *v_dup)
   return sub;
 }
 
+/**
+ * ncm_iset_get_subarray: (skip)
+ * @iset: a #NcmISet
+ * @a: a #GArray
+ * @a_dup: a #GArray
+ *
+ * Construct a continuous array using the values from @a
+ * and the indexes in @iset. If @a_dup is not null use
+ * this array to build the subarray, otherwise, allocates
+ * a new array.
+ *
+ * Returns: (transfer full): the subarray.
+ */
+GArray *
+ncm_iset_get_subarray (NcmISet *iset, GArray *a, GArray *a_dup)
+{
+  NcmISetPrivate *const self = iset->priv;
+  const guint nsub = g_queue_get_length (self->iq);
+  const guint esize = g_array_get_element_size (a);
+  GArray *sub;
+  GList *node;
+  gint i;
+
+  g_assert_cmpuint (self->n, ==, a->len);
+
+  if (a_dup != NULL)
+  {
+    g_assert_cmpuint (nsub, <=, a_dup->len);
+    g_assert_cmpuint (esize, ==, g_array_get_element_size (a_dup));
+    sub = a_dup;
+  }
+  else
+    sub = g_array_new (FALSE, FALSE, esize);
+
+  _ncm_iset_sort (iset);
+  node = g_queue_peek_head_link (self->iq);
+  i    = 0;
+
+  while (node != NULL)
+  {
+    const gint j = GPOINTER_TO_INT (node->data);
+    memcpy (&sub->data[i*esize], &a->data[j*esize], esize);
+
+    i++;
+    node = node->next;
+  }
+
+  return sub;
+}
+
+
 /**
  * ncm_iset_get_submatrix:
  * @iset: a #NcmISet
@@ -499,8 +550,8 @@ ncm_iset_get_submatrix (NcmISet *iset, NcmMatrix *M, NcmMatrix *M_dup)
 
   if (M_dup != NULL)
   {
-    g_assert_cmpuint (self->n, ==, ncm_matrix_nrows (M_dup));
-    g_assert_cmpuint (self->n, ==, ncm_matrix_ncols (M_dup));
+    g_assert_cmpuint (nsub, <=, ncm_matrix_nrows (M_dup));
+    g_assert_cmpuint (nsub, <=, ncm_matrix_ncols (M_dup));
 
     sub = ncm_matrix_get_submatrix (M_dup, 0, 0, nsub, nsub);
   }
@@ -540,7 +591,7 @@ ncm_iset_get_submatrix (NcmISet *iset, NcmMatrix *M, NcmMatrix *M_dup)
  * @M: a #NcmMatrix
  * @M_dup: a #NcmMatrix
  *
- * Construct a continuous matrix retangular $S$ using the columns
+ * Construct a continuous matrix rectangular $S$ using the columns
  * from the rectangular matrix @M and the indexes in @iset. If
  * @M_dup is not null use this matrix to build the submatrix,
  * otherwise, allocates a new matrix.
@@ -582,6 +633,9 @@ ncm_iset_get_submatrix_cols (NcmISet *iset, NcmMatrix *M, NcmMatrix *M_dup)
 
     ncm_vector_memcpy (col_i, col_k);
 
+    ncm_vector_free (col_i);
+    ncm_vector_free (col_k);
+
     i++;
     node = node->next;
   }
@@ -589,6 +643,65 @@ ncm_iset_get_submatrix_cols (NcmISet *iset, NcmMatrix *M, NcmMatrix *M_dup)
   return sub;
 }
 
+/**
+ * ncm_iset_get_submatrix_colmajor_cols:
+ * @iset: a #NcmISet
+ * @M: a #NcmMatrix
+ * @M_dup: a #NcmMatrix
+ *
+ * Construct a continuous matrix rectangular $S$ using the columns
+ * from the rectangular matrix @M and the indexes in @iset. If
+ * @M_dup is not null use this matrix to build the submatrix,
+ * otherwise, allocates a new matrix. It writes the columns in $S$
+ * using a colmajor memory scheme. This is useful when using
+ * the output matrix into Lapack routines.
+ *
+ * Returns: (transfer full): the matrix $S$.
+ */
+NcmMatrix *
+ncm_iset_get_submatrix_colmajor_cols (NcmISet *iset, NcmMatrix *M, NcmMatrix *M_dup)
+{
+  NcmISetPrivate *const self = iset->priv;
+  const guint nsub  = g_queue_get_length (self->iq);
+  const guint nrows = ncm_matrix_nrows (M);
+  const guint ncols = ncm_matrix_ncols (M);
+  NcmMatrix *sub;
+  GList *node;
+  gint i;
+
+  g_assert_cmpuint (self->n, ==, ncols);
+
+  if (M_dup != NULL)
+  {
+    g_assert_cmpuint (ncols, ==, ncm_matrix_ncols (M_dup));
+    g_assert_cmpuint (nrows, ==, ncm_matrix_nrows (M_dup));
+
+    sub = ncm_matrix_get_submatrix (M_dup, 0, 0, nrows, nsub);
+  }
+  else
+    sub = ncm_matrix_new (nrows, nsub);
+
+  _ncm_iset_sort (iset);
+  node = g_queue_peek_head_link (self->iq);
+  i    = 0;
+
+  while (node != NULL)
+  {
+    const gint k = GPOINTER_TO_INT (node->data);
+    gint j;
+
+    for (j = 0; j < nrows; j++)
+    {
+      const gdouble M_jk = ncm_matrix_get (M, j, k);
+      ncm_matrix_set_colmajor (sub, j, i, M_jk);
+    }
+
+    i++;
+    node = node->next;
+  }
+
+  return sub;
+}
 
 /**
  * ncm_iset_get_sym_submatrix:
