@@ -32,6 +32,7 @@
 #include <numcosmo/math/ncm_cfg.h>
 #include <numcosmo/math/ncm_sparam.h>
 #include <numcosmo/math/ncm_vparam.h>
+#include <numcosmo/math/ncm_obj_array.h>
 
 G_BEGIN_DECLS
 
@@ -77,6 +78,11 @@ void ncm_model_builder_add_vparam (NcmModelBuilder *mb, guint default_length, co
 
 GType ncm_model_builder_create (NcmModelBuilder *mb);
 
+void ncm_model_builder_add_sparams (NcmModelBuilder *mb, NcmObjArray *sparams);
+NcmObjArray *ncm_model_builder_get_sparams (NcmModelBuilder *mb);
+
+
 G_END_DECLS
 
 #endif /* _NCM_MODEL_BUILDER_H_ */
+
