@@ -62,10 +62,11 @@ gint
 main (gint argc, gchar *argv[])
 {
   gint i;
-  
+
   g_test_init (&argc, &argv, NULL);
   ncm_cfg_init_full_ptr (&argc, &argv);
   ncm_cfg_enable_gsl_err_handler ();
+
   gpointer ccc[TEST_NCM_MODEL_NTYPES][3] = {
     {"model",            &test_ncm_model_new,             &test_ncm_model_free},
     {"model/modified",   &test_ncm_model_new_modify,      &test_ncm_model_free},
@@ -73,52 +74,52 @@ main (gint argc, gchar *argv[])
     {"model/grandchild", &test_ncm_model_child_child_new, &test_ncm_model_free},
     {"model/reparam",    &test_ncm_model_reparam_new,     &test_ncm_model_free},
   };
-  
+
   for (i = 0; i < TEST_NCM_MODEL_NTYPES; i++)
   {
     gchar *d;
-    
+
     d = g_strdup_printf ("/ncm/%s/new", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_new, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/length", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_length, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/defval", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_defval, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/name_symbol", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_name_symbol, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/setget", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_setget, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/setget/prop", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_setget_prop, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/setget/vector", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_setget_vector, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/setget/model", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_setget_model, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/name_index", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_name_index, ccc[i][2]);
     g_free (d);
-    
+
     d = g_strdup_printf ("/ncm/%s/dup", (gchar *) ccc[i][0]);
     g_test_add (d, TestNcmModel, NULL, ccc[i][1], &test_ncm_model_test_dup, ccc[i][2]);
     g_free (d);
   }
-  
+
   g_test_run ();
 }
 
@@ -132,7 +133,7 @@ test_ncm_model_new (TestNcmModel *test, gconstpointer pdata)
   test->name       = name_tot[0];
   test->nick       = nick_tot[0];
   test->reparam    = NULL;
-  
+
   g_assert_true (test->type != 0);
 }
 
@@ -146,12 +147,12 @@ test_ncm_model_new_modify (TestNcmModel *test, gconstpointer pdata)
   test->name       = name_tot[0];
   test->nick       = nick_tot[0];
   test->reparam    = NULL;
-  
+
   {
     NcmModel *model = NCM_MODEL (test->tm);
     guint model_len = ncm_model_len (model);
     guint i;
-    
+
     for (i = 0; i < model_len; i++)
     {
       const gdouble curval   = ncm_model_param_get (model, i);
@@ -159,7 +160,7 @@ test_ncm_model_new_modify (TestNcmModel *test, gconstpointer pdata)
       const gdouble s_ub     = g_test_rand_double_range (s_lb, curval + fabs (curval) * 1.5);
       const gdouble s_scale  = fabs (((s_ub + s_lb) != 0 ? (s_ub + s_lb) : 1.0) * pow (10.0, -g_test_rand_double_range (1.0,  2.0)));
       const gdouble s_abstol = s_scale * pow (10.0, -g_test_rand_double_range (1.0, 11.0));
-      
+
       ncm_model_param_set_upper_bound (model, i, GSL_POSINF);
       ncm_model_param_set_lower_bound (model, i, s_lb);
       ncm_model_param_set_upper_bound (model, i, s_ub);
@@ -167,7 +168,7 @@ test_ncm_model_new_modify (TestNcmModel *test, gconstpointer pdata)
       ncm_model_param_set_abstol (model, i, s_abstol);
     }
   }
-  
+
   g_assert_true (test->type != 0);
 }
 
@@ -181,7 +182,7 @@ test_ncm_model_child_new (TestNcmModel *test, gconstpointer pdata)
   test->name       = name_tot[1];
   test->nick       = nick_tot[1];
   test->reparam    = NULL;
-  
+
   g_assert_true (test->type != 0);
 }
 
@@ -195,7 +196,7 @@ test_ncm_model_child_child_new (TestNcmModel *test, gconstpointer pdata)
   test->name       = name_tot[2];
   test->nick       = nick_tot[2];
   test->reparam    = NULL;
-  
+
   g_assert_true (test->type != 0);
 }
 
@@ -210,30 +211,30 @@ _test_ncm_model_create_reparam (TestNcmModel *test)
   guint cdesc_n        = size / 10;
   NcmReparamLinear *relin;
   guint i;
-  
+
   if (cdesc_n == 0)
     cdesc_n = 1;
-  
+
   ncm_bootstrap_remix (bstrap, rng);
-  
+
   ncm_matrix_set_zero (T);
   ncm_vector_set_zero (v);
-  
+
   for (i = 0; i < size; i++)
   {
     ncm_matrix_set (T, i, ncm_bootstrap_get (bstrap, i), g_test_rand_double_range (1.0, 10.0));
     ncm_vector_set (v, i, g_test_rand_double ());
   }
-  
+
   relin = ncm_reparam_linear_new (size, T, v);
   ncm_reparam_linear_set_compat_type (relin, NCM_TYPE_MODEL_TEST);
-  
+
   for (i = 0; i < cdesc_n; i++)
   {
     guint j                 = g_test_rand_int_range (0, size - 1);
     gchar *new_param        = g_strdup_printf ("new_param_%u", j);
     gchar *new_param_symbol = g_strdup_printf ("NP_%u", j);
-    
+
     ncm_reparam_set_param_desc_full (NCM_REPARAM (relin),
                                      j,
                                      new_param,
@@ -247,14 +248,14 @@ _test_ncm_model_create_reparam (TestNcmModel *test)
     g_free (new_param);
     g_free (new_param_symbol);
   }
-  
+
   ncm_model_set_reparam (NCM_MODEL (test->tm), NCM_REPARAM (relin));
   ncm_reparam_free (NCM_REPARAM (relin));
-  
+
   ncm_vector_free (v);
   ncm_matrix_free (T);
   ncm_rng_free (rng);
-  
+
   return NCM_REPARAM (relin);
 }
 
@@ -268,7 +269,7 @@ test_ncm_model_reparam_new (TestNcmModel *test, gconstpointer pdata)
   test->name       = name_tot[0];
   test->nick       = nick_tot[0];
   test->reparam    = _test_ncm_model_create_reparam (test);
-  
+
   g_assert_true (test->type != 0);
 }
 
@@ -283,17 +284,17 @@ test_ncm_model_test_new (TestNcmModel *test, gconstpointer pdata)
 {
   NcmModelTest *tm = test->tm;
   NcmModel *model;
-  
+
   g_assert_true (NCM_IS_MODEL (tm));
   g_assert_true (NCM_IS_MODEL_TEST (tm));
   model = NCM_MODEL (tm);
-  
+
   g_assert_true (ncm_model_name (model) != test->name);
   g_assert_true (ncm_model_nick (model) != test->nick);
-  
+
   g_assert_cmpstr (ncm_model_name (model), ==, test->name);
   g_assert_cmpstr (ncm_model_nick (model), ==, test->nick);
-  
+
   g_assert_true (ncm_model_peek_reparam (model) == test->reparam);
 }
 
@@ -304,15 +305,15 @@ test_ncm_model_test_length (TestNcmModel *test, gconstpointer pdata)
   NcmModel *model  = NCM_MODEL (tm);
   guint model_len  = 0;
   guint i;
-  
+
   model_len = test->sparam_len;
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     g_assert_cmpint (ncm_model_vparam_len (model, i), ==, v_len_tot[i]);
     model_len += v_len_tot[i];
   }
-  
+
   g_assert_cmpint (ncm_model_len (model), ==, model_len);
   g_assert_cmpint (ncm_model_sparam_len (model), ==, test->sparam_len);
   g_assert_cmpint (ncm_model_vparam_array_len (model), ==, test->vparam_len);
@@ -324,22 +325,22 @@ test_ncm_model_test_defval (TestNcmModel *test, gconstpointer pdata)
   NcmModelTest *tm = test->tm;
   NcmModel *model  = NCM_MODEL (tm);
   guint i;
-  
+
   for (i = 0; i < test->sparam_len; i++)
   {
     gdouble p = ncm_model_orig_param_get (model, i);
-    
+
     ncm_assert_cmpdouble (p, ==, s_defval_tot[i]);
   }
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     guint j;
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       gdouble p = ncm_model_orig_vparam_get (model, i, j);
-      
+
       ncm_assert_cmpdouble (p, ==, v_defval_tot[i]);
     }
   }
@@ -351,34 +352,34 @@ test_ncm_model_test_name_symbol (TestNcmModel *test, gconstpointer pdata)
   NcmModelTest *tm = test->tm;
   NcmModel *model  = NCM_MODEL (tm);
   guint i;
-  
+
   for (i = 0; i < test->sparam_len; i++)
   {
     const gchar *pname   = ncm_model_orig_param_name (model, i);
     const gchar *psymbol = ncm_model_orig_param_symbol (model, i);
-    
+
     g_assert_true (pname != s_name_tot[i]);
     g_assert_true (psymbol != s_symbol_tot[i]);
     g_assert_cmpstr (pname, ==, s_name_tot[i]);
     g_assert_cmpstr (psymbol, ==, s_symbol_tot[i]);
   }
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     guint j;
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       gchar *vp_name       = g_strdup_printf ("%s_%u", v_name_tot[i], j);
-      gchar *vp_symbol     = g_strdup_printf ("%s_%u", v_symbol_tot[i], j);
+      gchar *vp_symbol     = g_strdup_printf ("{%s}_%u", v_symbol_tot[i], j);
       const gchar *pname   = ncm_model_orig_param_name (model, ncm_model_vparam_index (model, i, j));
       const gchar *psymbol = ncm_model_orig_param_symbol (model, ncm_model_vparam_index (model, i, j));
-      
+
       g_assert_true (pname != vp_name);
       g_assert_true (psymbol != vp_symbol);
       g_assert_cmpstr (pname, ==, vp_name);
       g_assert_cmpstr (psymbol, ==, vp_symbol);
-      
+
       g_free (vp_name);
       g_free (vp_symbol);
     }
@@ -392,26 +393,26 @@ test_ncm_model_test_finite (TestNcmModel *test, gconstpointer pdata)
   NcmModel *model  = NCM_MODEL (tm);
   guint model_len  = ncm_model_len (model);
   guint i;
-  
+
   for (i = 0; i < model_len; i++)
   {
     g_assert_true (ncm_model_param_finite (model, i));
     g_assert_true (ncm_model_params_finite (model));
-    
+
     ncm_model_param_set (model, i, GSL_NAN);
     g_assert_true (!ncm_model_param_finite (model, i));
     g_assert_true (!ncm_model_params_finite (model));
     ncm_model_param_set_default (model, i);
     g_assert_true (ncm_model_param_finite (model, i));
     g_assert_true (ncm_model_params_finite (model));
-    
+
     ncm_model_param_set (model, i, GSL_POSINF);
     g_assert_true (!ncm_model_param_finite (model, i));
     g_assert_true (!ncm_model_params_finite (model));
     ncm_model_param_set_default (model, i);
     g_assert_true (ncm_model_param_finite (model, i));
     g_assert_true (ncm_model_params_finite (model));
-    
+
     ncm_model_param_set (model, i, GSL_NEGINF);
     g_assert_true (!ncm_model_param_finite (model, i));
     g_assert_true (!ncm_model_params_finite (model));
@@ -429,86 +430,86 @@ test_ncm_model_test_setget (TestNcmModel *test, gconstpointer pdata)
   guint model_len  = ncm_model_len (model);
   NcmVector *tmp   = ncm_vector_new (model_len);
   guint i;
-  
+
   /* ncm_model_param_get / ncm_model_param_set */
-  
+
   for (i = 0; i < model_len; i++)
   {
     const gdouble lb = ncm_model_param_get_lower_bound (model, i);
     const gdouble ub = ncm_model_param_get_upper_bound (model, i);
     gdouble val;
-    
+
     while ((val = g_test_rand_double_range (lb, ub)))
     {
       if (val != ncm_model_param_get (model, i))
         break;
     }
-    
+
     ncm_model_param_set (model, i, val);
     ncm_assert_cmpdouble (ncm_model_param_get (model, i), ==, val);
-    
+
     ncm_model_param_set_default (model, i);
     ncm_assert_cmpdouble (ncm_model_param_get (model, i), !=, val);
-    
+
     ncm_model_param_set (model, i, val);
     ncm_vector_set (tmp, i, val);
   }
-  
+
   /* ncm_model_params_save_as_default */
   ncm_model_params_save_as_default (model);
-  
+
   for (i = 0; i < model_len; i++)
   {
     ncm_assert_cmpdouble (ncm_model_param_get (model, i), ==, ncm_vector_get (tmp, i));
   }
-  
+
   for (i = 0; i < test->sparam_len; i++)
   {
     ncm_model_param_set (model, i, s_defval_tot[i]);
   }
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     guint j;
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       ncm_model_param_set (model, ncm_model_vparam_index (model, i, j), v_defval_tot[i]);
     }
   }
-  
+
   ncm_model_params_set_default (model);
-  
+
   for (i = 0; i < model_len; i++)
   {
     ncm_assert_cmpdouble (ncm_model_param_get (model, i), ==, ncm_vector_get (tmp, i));
   }
-  
+
   for (i = 0; i < test->sparam_len; i++)
   {
     ncm_model_param_set (model, i, s_defval_tot[i]);
   }
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     guint j;
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       ncm_model_param_set (model, ncm_model_vparam_index (model, i, j), v_defval_tot[i]);
     }
   }
-  
+
   ncm_model_params_save_as_default (model);
-  
+
   /* ncm_model_params_set_all_data */
   ncm_model_params_set_all_data (model, ncm_vector_data (tmp));
-  
+
   for (i = 0; i < model_len; i++)
   {
     ncm_assert_cmpdouble (ncm_model_param_get (model, i), ==, ncm_vector_get (tmp, i));
   }
-  
+
   ncm_vector_free (tmp);
 }
 
@@ -518,60 +519,60 @@ test_ncm_model_test_setget_prop (TestNcmModel *test, gconstpointer pdata)
   NcmModelTest *tm = test->tm;
   NcmModel *model  = NCM_MODEL (tm);
   guint i;
-  
+
   /* ncm_model_param_get / ncm_model_param_set */
-  
+
   for (i = 0; i < test->sparam_len; i++)
   {
     gdouble lb = ncm_model_orig_param_get_lower_bound (model, i);
     gdouble ub = ncm_model_orig_param_get_upper_bound (model, i);
     gdouble val, val_out;
-    
+
     while ((val = g_test_rand_double_range (lb, ub)))
     {
       if (val != ncm_model_orig_param_get (model, i))
         break;
     }
-    
+
     g_object_set (model, s_name_tot[i], val, NULL);
     g_object_get (model, s_name_tot[i], &val_out, NULL);
     ncm_assert_cmpdouble (val_out, ==, val);
   }
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     NcmVector *tmp     = ncm_vector_new (v_len_tot[i]);
     NcmVector *tmp_out = NULL;
     guint j;
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       guint n    = ncm_model_vparam_index (model, i, j);
       gdouble lb = ncm_model_orig_param_get_lower_bound (model, n);
       gdouble ub = ncm_model_orig_param_get_upper_bound (model, n);
       gdouble val;
-      
+
       while ((val = g_test_rand_double_range (lb, ub)))
       {
         if (val != ncm_model_orig_param_get (model, n))
           break;
       }
-      
+
       ncm_vector_set (tmp, j, val);
     }
-    
+
     tmp_out = NULL;
     g_object_set (model, v_name_tot[i], tmp, NULL);
     g_object_get (model, v_name_tot[i], &tmp_out, NULL);
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       guint n = ncm_model_vparam_index (model, i, j);
-      
+
       ncm_assert_cmpdouble (ncm_vector_get (tmp, j), ==, ncm_model_orig_param_get (model, n));
       ncm_assert_cmpdouble (ncm_vector_get (tmp, j), ==, ncm_vector_get (tmp_out, j));
     }
-    
+
     NCM_TEST_FREE (ncm_vector_free, tmp);
     NCM_TEST_FREE (ncm_vector_free, tmp_out);
   }
@@ -583,7 +584,7 @@ test_ncm_model_test_setget_vector (TestNcmModel *test, gconstpointer pdata)
   NcmModelTest *tm = test->tm;
   NcmModel *model  = NCM_MODEL (tm);
   guint model_len  = ncm_model_len (model);
-  
+
   NCM_TEST_FAIL (G_STMT_START {
     NcmVector *tmp2 = ncm_vector_new (model_len + 1);
     ncm_model_params_set_vector (model, tmp2);
@@ -605,37 +606,37 @@ test_ncm_model_test_setget_model (TestNcmModel *test, gconstpointer pdata)
   NcmModel *model3 = NCM_MODEL (tm3);
   guint model_len  = ncm_model_len (model1);
   guint i;
-  
+
   ncm_serialize_free (ser);
-  
+
   g_assert_true (ncm_model_is_equal (model1, model2));
   g_assert_true (!ncm_model_is_equal (model1, model3));
-  
+
   for (i = 0; i < model_len; i++)
   {
     gdouble lb = ncm_model_param_get_lower_bound (model2, i);
     gdouble ub = ncm_model_param_get_upper_bound (model2, i);
     gdouble val;
-    
+
     while ((val = g_test_rand_double_range (lb, ub)))
     {
       if (val != ncm_model_param_get (model2, i))
         break;
     }
-    
+
     ncm_model_param_set (model2, i, val);
   }
-  
+
   ncm_model_params_set_model (model1, model2);
-  
+
   for (i = 0; i < model_len; i++)
   {
     ncm_assert_cmpdouble (ncm_model_param_get (model1, i), ==, ncm_model_param_get (model2, i));
   }
-  
+
   g_assert_true (!ncm_model_is_equal (model1, model3));
   g_assert_true (!ncm_model_is_equal (model3, model1));
-  
+
   NCM_TEST_FREE (ncm_model_free, model2);
   NCM_TEST_FREE (ncm_model_free, model3);
 }
@@ -646,37 +647,37 @@ test_ncm_model_test_name_index (TestNcmModel *test, gconstpointer pdata)
   NcmModelTest *tm = test->tm;
   NcmModel *model  = NCM_MODEL (tm);
   guint i;
-  
+
   for (i = 0; i < test->sparam_len; i++)
   {
     guint n;
     gboolean found          = ncm_model_orig_param_index_from_name (model, s_name_tot[i], &n);
     const gchar *s_name_n   = ncm_model_orig_param_name (model, n);
     const gchar *s_symbol_n = ncm_model_orig_param_symbol (model, n);
-    
+
     g_assert_true (found);
     g_assert_cmpuint (n, ==, i);
     g_assert_cmpstr (s_name_n, ==, s_name_tot[n]);
     g_assert_cmpstr (s_symbol_n, ==, s_symbol_tot[n]);
   }
-  
+
   for (i = 0; i < test->vparam_len; i++)
   {
     guint j;
-    
+
     for (j = 0; j < v_len_tot[i]; j++)
     {
       gchar *v_name_ij   = g_strdup_printf ("%s_%u", v_name_tot[i], j);
-      gchar *v_symbol_ij = g_strdup_printf ("%s_%u", v_symbol_tot[i], j);
+      gchar *v_symbol_ij = g_strdup_printf ("{%s}_%u", v_symbol_tot[i], j);
       guint n;
       gboolean found          = ncm_model_orig_param_index_from_name (model, v_name_ij, &n);
       const gchar *v_name_n   = ncm_model_orig_param_name (model, n);
       const gchar *v_symbol_n = ncm_model_orig_param_symbol (model, n);
-      
+
       g_assert_true (found);
       g_assert_cmpstr (v_name_n, ==, v_name_ij);
       g_assert_cmpstr (v_symbol_n, ==, v_symbol_ij);
-      
+
       g_free (v_name_ij);
       g_free (v_symbol_ij);
     }
@@ -692,10 +693,10 @@ test_ncm_model_test_dup (TestNcmModel *test, gconstpointer pdata)
   NcmModel *model_dup = ncm_model_dup (model, ser);
   guint model_len     = ncm_model_len (model);
   guint i;
-  
+
   ncm_serialize_free (ser);
   g_assert_true (ncm_model_is_equal (model, model_dup));
-  
+
   for (i = 0; i < model_len; i++)
   {
     ncm_assert_cmpdouble (ncm_model_param_get (model, i),             ==, ncm_model_param_get (model_dup, i));
